@@ -1,9 +1,9 @@
 /*
  * pg_filedump.c - PostgreSQL file dump utility for dumping and
  *                 formatting heap (data), index and control files.
- *                 Version 8.3.0 for PostgreSQL 8.3
+ *                 Version 8.4.0 for PostgreSQL 8.4
  *
- * Copyright (c) 2002-2008 Red Hat, Inc. All rights reserved.
+ * Copyright (c) 2002-2009 Red Hat, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -63,7 +63,7 @@ DisplayOptions (unsigned int validOptions)
 {
   if (validOptions == OPT_RC_COPYRIGHT)
     printf
-      ("\nVersion 8.3.0 (PostgreSQL 8.3)  Copyright (c) 2002-2008 Red Hat, Inc.\n");
+      ("\nVersion 8.4.0 (PostgreSQL 8.4)  Copyright (c) 2002-2009 Red Hat, Inc.\n");
 
   printf
     ("\nUsage: pg_filedump [-abcdfhixy] [-R startblock [endblock]] [-S blocksize] file\n\n"
@@ -528,7 +528,7 @@ CreateDumpFileHeader (int numOptions, char **options)
 
   printf
     ("\n*******************************************************************\n"
-     "* PostgreSQL File/Block Formatted Dump Utility - Version 8.3.0\n*\n"
+     "* PostgreSQL File/Block Formatted Dump Utility - Version 8.4.0\n*\n"
      "* File: %s\n"
      "* Options used: %s\n*\n"
      "* Dump created on: %s"
@@ -1169,10 +1169,7 @@ FormatControl ()
 	      "    Maximum Identifier Length: %u\n"
 	      "           Maximum Index Keys: %u\n"
 	      "             TOAST Chunk Size: %u\n"
-	      "   Date and Time Type Storage: %s\n"
-	      "         Locale Buffer Length: %u\n"
-	      "                   lc_collate: %s\n"
-	      "                     lc_ctype: %s\n\n",
+	      "   Date and Time Type Storage: %s\n\n",
 	      EQ_CRC32 (crcLocal,
 			controlData->crc) ? "Correct" : "Not Correct",
 	      controlData->pg_control_version,
@@ -1203,10 +1200,7 @@ FormatControl ()
 	      controlData->indexMaxKeys,
 	      controlData->toast_max_chunk_size,
 	      (controlData->enableIntTimes ?
-	       "64 bit Integers" : "Floating Point"),
-	      controlData->localeBuflen,
-	      controlData->lc_collate,
-	      controlData->lc_ctype);
+	       "64 bit Integers" : "Floating Point"));
     }
   else
     {
